initZeroPtrList
(
    forcesSourcef, mesh, dimensionSet(1, 0, -2, 0, 0), "forcesSourcef"
);

// Add lift force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::FlfTable, fluid.Flfs(), FlfIter)
{
    const surfaceScalarField& Ff(*FlfIter());
    const phasePair& pair(fluid.phasePairs()[FlfIter.key()]);

    forcesSourcef[pair.phase1().index()] -= Ff;
    forcesSourcef[pair.phase2().index()] += Ff;
}

// Add wall lubrication force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::FwfTable, fluid.Fwfs(), FwfIter)
{
    const surfaceScalarField& Ff(*FwfIter());
    const phasePair& pair(fluid.phasePairs()[FwfIter.key()]);

    forcesSourcef[pair.phase1().index()] -= Ff;
    forcesSourcef[pair.phase2().index()] += Ff;
}

// Add turbulent dispersion force
// Inspired by MomentumTransferPhaseSystem::phiFfs()
forAllConstIter(phaseSystem::DtTable, fluid.Dts(), DtIter)
{
    const volScalarField& D(*DtIter());
    const phasePair& pair(fluid.phasePairs()[DtIter.key()]);

    const phaseModel& phase1(pair.phase1());
    const phaseModel& phase2(pair.phase2());

    const surfaceScalarField alphaf12
    (
        max
        (
            alphafs[phase1.index()] + alphafs[phase2.index()],
            phase1.residualAlpha() + phase2.residualAlpha()
        )
    );

    const surfaceScalarField Ff
    (
        fvc::interpolate(D)*pair.gradAlphaf()/sqr(alphaf12)
       *phase1.mesh().magSf()
    );

    forcesSourcef[phase1.index()] -= Ff;
    forcesSourcef[phase2.index()] += Ff;
}
