/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | Copyright (C) 2019-2022 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "residualDrag.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"
#include "surfaceInterpolate.H"
#include "fvcGrad.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace dragModels
{
    defineTypeNameAndDebug(residualDrag, 0);
    addToRunTimeSelectionTable(dragModel, residualDrag, dictionary);
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::dragModels::residualDrag::residualDrag
(
    const dictionary& dict,
    const phasePair& pair,
    const bool registerObject
)
:
    dragModel(dict, pair, registerObject),
    residualK_("value", dimensionSet(1, -3, -1, 0, 0), dict)
{
    if (pair.dispersed().continuous() || !pair.continuous().continuous())
    {
        FatalErrorInFunction
            << "Expecting an ordered pair of (disperse in continuous) "
            << "in pair " << pair.name() << " for " << typeName << " model."
            << exit(FatalError);
    }
}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::dragModels::residualDrag::~residualDrag()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField> Foam::dragModels::residualDrag::CdRe() const
{
    NotImplemented;
    return tmp<volScalarField>(nullptr);
}


Foam::tmp<Foam::volScalarField> Foam::dragModels::residualDrag::Ki() const
{
    NotImplemented;
    return tmp<volScalarField>(nullptr);
}


Foam::tmp<Foam::volScalarField> Foam::dragModels::residualDrag::K() const
{
    const phaseModel& disp = pair_.dispersed();
    const phaseModel& cont = pair_.continuous();

    const dimensionedScalar& residualAlphaD = disp.residualAlpha();
    const dimensionedScalar& residualAlphaC = cont.residualAlpha();

    return neg(disp - residualAlphaD)*pos(cont - residualAlphaC)*residualK_;
}


Foam::tmp<Foam::surfaceScalarField>Foam::dragModels::residualDrag::Kf() const
{
    return fvc::interpolate(K());
}


// ************************************************************************* //
