/*---------------------------------------------------------------------------*\
  ==  == ====== ====   ====    |
                    \\     ||  | HZDR Multiphase Addon for OpenFOAM
  ======   //   ||  || ===//   | Website: https://doi.org/10.14278/rodare.767
  ||  ||  //    ||  // || \\   | Copyright (C) 2021 OpenFOAM Foundation
  ==  == ====== ====   ==  ==  | and Helmholtz-Zentrum Dresden-Rossendorf
-------------------------------------------------------------------------------
License
    This file is a derivative work of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "continuumSurfaceForce.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"
#include "alphaContactAngleFvPatchScalarField.H"
#include "unitConversion.H"
#include "fvc.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace surfaceTensionForceModels
{
    defineTypeNameAndDebug(continuumSurfaceForce, 0);
    addToRunTimeSelectionTable
    (
        surfaceTensionForceModel,
        continuumSurfaceForce,
        dictionary
    );
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::continuumSurfaceForce::continuumSurfaceForce
(
    const phaseSystem& fluid
)
:
    surfaceTensionForceModel(fluid)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::surfaceTensionForceModels::continuumSurfaceForce::~continuumSurfaceForce()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::surfaceTensionForceModels::continuumSurfaceForce::K
(
    const phasePair& pair
) const
{
    tmp<surfaceVectorField> tnHatfv = pair.nHatfv();

    fluid_.correctContactAngle
    (
        pair.phase1(),
        pair.phase2(),
        tnHatfv.ref().boundaryFieldRef()
    );

    return -fvc::div(tnHatfv & fluid_.mesh().Sf());
}


// ************************************************************************* //
