/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2014-2021 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "orderedPhasePair.H"
#include "phaseSystem.H"

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::orderedPhasePair::orderedPhasePair
(
    const phaseModel& dispersed,
    const phaseModel& continuous
)
:
    phasePair
    (
        dispersed,
        continuous,
        true
    )
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::orderedPhasePair::~orderedPhasePair()
{}


// * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * * //

const Foam::phaseModel& Foam::orderedPhasePair::dispersed() const
{
    return phase1();
}


const Foam::phaseModel& Foam::orderedPhasePair::continuous() const
{
    return phase2();
}


Foam::word Foam::orderedPhasePair::name() const
{
    word namec(second());
    namec[0] = toupper(namec[0]);
    return first() + "In" + namec;
}


Foam::word Foam::orderedPhasePair::otherName() const
{
    FatalErrorInFunction
        << "Requested other name phase from an ordered pair."
        << exit(FatalError);

    return word::null;
}


//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
Foam::tmp<Foam::volScalarField> Foam::orderedPhasePair::Ai() const
{
    return 6.0*phase1()/phase1().d();
}


Foam::tmp<Foam::volVectorField> Foam::orderedPhasePair::gradAlpha() const
{
    FatalErrorInFunction
        << "Requested interface gradient from an ordered pair."
        << exit(FatalError);

    return tmp<volVectorField>(nullptr);
}


Foam::tmp<Foam::surfaceVectorField> Foam::orderedPhasePair::gradAlphafv() const
{
    FatalErrorInFunction
        << "Requested face interface gradient from an ordered pair."
        << exit(FatalError);

    return tmp<surfaceVectorField>(nullptr);
}


Foam::tmp<Foam::surfaceScalarField> Foam::orderedPhasePair::gradAlphaf() const
{
    FatalErrorInFunction
        << "Requested interface gradient flux from an ordered pair."
        << exit(FatalError);

    return tmp<surfaceScalarField>(nullptr);
}


Foam::tmp<Foam::volVectorField> Foam::orderedPhasePair::nHat() const
{
    FatalErrorInFunction
        << "Requested interface normal from an ordered pair."
        << exit(FatalError);

    return tmp<volVectorField>(nullptr);
}


Foam::tmp<Foam::surfaceVectorField> Foam::orderedPhasePair::nHatfv() const
{
    FatalErrorInFunction
        << "Requested face interface normal from an ordered pair."
        << exit(FatalError);

    return tmp<surfaceVectorField>(nullptr);
}


Foam::tmp<Foam::surfaceScalarField> Foam::orderedPhasePair::nHatf() const
{
    FatalErrorInFunction
        << "Requested interface normal flux from an ordered pair."
        << exit(FatalError);

    return tmp<surfaceScalarField>(nullptr);
}


Foam::tmp<Foam::volScalarField> Foam::orderedPhasePair::K() const
{
    FatalErrorInFunction
        << "Requested interface curvature from an ordered pair."
        << exit(FatalError);

    return tmp<volScalarField>(nullptr);
}
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//


// ************************************************************************* //
