/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     | Website:  https://openfoam.org
    \\  /    A nd           | Copyright (C) 2014-2021 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::orderedPhasePair

Description

SourceFiles
    orderedPhasePair.C

\*---------------------------------------------------------------------------*/

#ifndef orderedPhasePair_H
#define orderedPhasePair_H

#include "phasePair.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                      Class orderedPhasePair Declaration
\*---------------------------------------------------------------------------*/

class orderedPhasePair
:
    public phasePair
{

public:

    // Constructors

        //- Construct from two phases and gravity
        orderedPhasePair
        (
            const phaseModel& dispersed,
            const phaseModel& continuous
        );


    //- Destructor
    virtual ~orderedPhasePair();


    // Member Functions

        //- Dispersed phase
        virtual const phaseModel& dispersed() const;

        //- Continuous phase
        virtual const phaseModel& continuous() const;

        //- Pair name
        virtual word name() const;

        //- Other pair name
        virtual word otherName() const;

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Begin HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
        //- Interfacial area density
        virtual tmp<volScalarField> Ai() const;

        //- Interface gradient between two phases
        virtual tmp<volVectorField> gradAlpha() const;

        //- Face interface gradient between two phases
        virtual tmp<surfaceVectorField> gradAlphafv() const;

        //- Interface gradient flux between two phases
        virtual tmp<surfaceScalarField> gradAlphaf() const;

        //- Normal to interface between two phases
        virtual tmp<volVectorField> nHat() const;

        //- Normal to interface between two phases
        virtual tmp<surfaceVectorField> nHatfv() const;

        //- Normal to interface between two phases dotted with face areas
        virtual tmp<surfaceScalarField> nHatf() const;

        //- Interface curvature
        virtual tmp<volScalarField> K() const;
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ End HZDR ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~//
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
